;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; EFS based simulator
; program used to calculate budget elasticities
; changes to real income are effected by modifying the incanon variable
; when income varies, the expenditure pattern of a household with the previous incanon
; is copied to the current household.
; modified for bt ptoject summer 2009
; modified from base model peakoil 11
; updating stops when mean population income has reached target to stop overrunning
; program used to obtain results for random assignment paper
; all households processed
; donor taken from next higher or lower income household by 50/50 probability
; pc output files relate to preportion of mean expenditure for each category
; uses equivalised expenditures for disaggregated caregories
; last modified 24.5.2013
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; area for setting patameter values
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to set_scenareo  ; initialise scenareo parameters

;  set change_in_non_comms_based_expenditure% 10  
;  set income_inflation% 5.0
;  if years = 0 [set income_inflation% 1.3]
;  if years = 1 [set income_inflation% 2.0]
;  if years = 2 [set income_inflation% 4.0]    
;  if years = 3 [set income_inflation% 0.5]
;  if years = 4 [set income_inflation% 1.8]    
      
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; data description
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

globals [
  pop years hsize houses myage currentcase currenthouse maxhouseholds
  totfood totalcohol totclothing tothousing totfurniture tothealth tottransport totcommunication
  totrecreation toteduc tothotels totmisc tototherexp totoldhhincome    
  houses2 houses4 housesq1 housesq2 housesq3 housesq4 housesq5 totincome2 totincome4
  totseconddwelling income pcexpcommunication pcexpseconddwelling pcexpinternet
  tottelecom totnontelecom pcexptelecom pcexpnontelecom pcinctelecom pcincnontelecom
  etotfood etotalcohol etotclothing etothousing etotfurniture etothealth etottransport etotcommunication
  etotrecreation etoteduc etothotels etotmisc etototherexp etotoldhhincome
  
  totfood2 totalcohol2 totclothing2 tothousing2 totfurniture2 tothealth2 tottransport2 totcommunication2  
  totrecreation2 toteduc2 tothotels2 totmisc2 tototherexp2
  totfood4 totalcohol4 totclothing4 tothousing4 totfurniture4 tothealth4 tottransport4 totcommunication4  
  totrecreation4 toteduc4 tothotels4 totmisc4 tototherexp4

  etotfood2 etotalcohol2 etotclothing2 etothousing2 etotfurniture2 etothealth2 etottransport2 etotcommunication2  
  etotrecreation2 etoteduc2 etothotels2 etotmisc2 etototherexp2
  etotfood4 etotalcohol4 etotclothing4 etothousing4 etotfurniture4 etothealth4 etottransport4 etotcommunication4  
  etotrecreation4 etoteduc4 etothotels4 etotmisc4 etototherexp4

; quintile 1 variables
  totfoodq1 totalcoholq1 totclothingq1 tothousingq1 totfurnitureq1 tothealthq1 tottransportq1 totcommunicationq1  
  totrecreationq1 toteducq1 tothotelsq1 totmiscq1 tototherexpq1 totexpq1 totincomeq1
  meanfoodq1 meanalcoholq1 meanclothingq1 meanhousingq1 meanfurnitureq1 meanhealthq1 meantransportq1 meancommunicationq1
  meanrecreationq1 meaneducq1 meanhotelsq1 meanmiscq1 meanotherexpq1 meanincomeq1 meanexpq1
  
; quintile 2 variables  
  totfoodq2 totalcoholq2 totclothingq2 tothousingq2 totfurnitureq2 tothealthq2 tottransportq2 totcommunicationq2  
  totrecreationq2 toteducq2 tothotelsq2 totmiscq2 tototherexpq2 totexpq2 totincomeq2
  meanfoodq2 meanalcoholq2 meanclothingq2 meanhousingq2 meanfurnitureq2 meanhealthq2 meantransportq2 meancommunicationq2
  meanrecreationq2 meaneducq2 meanhotelsq2 meanmiscq2 meanotherexpq2 meanincomeq2 meanexpq2 

; quintile 3 variables  
  totfoodq3 totalcoholq3 totclothingq3 tothousingq3 totfurnitureq3 tothealthq3 tottransportq3 totcommunicationq3  
  totrecreationq3 toteducq3 tothotelsq3 totmiscq3 tototherexpq3 totexpq3 totincomeq3
  meanfoodq3 meanalcoholq3 meanclothingq3 meanhousingq3 meanfurnitureq3 meanhealthq3 meantransportq3 meancommunicationq3
  meanrecreationq3 meaneducq3 meanhotelsq3 meanmiscq3 meanotherexpq3 meanincomeq3 meanexpq3

; quintile 4 variables  
  totfoodq4 totalcoholq4 totclothingq4 tothousingq4 totfurnitureq4 tothealthq4 tottransportq4 totcommunicationq4  
  totrecreationq4 toteducq4 tothotelsq4 totmiscq4 tototherexpq4 totexpq4 totincomeq4
  meanfoodq4 meanalcoholq4 meanclothingq4 meanhousingq4 meanfurnitureq4 meanhealthq4 meantransportq4 meancommunicationq4
  meanrecreationq4 meaneducq4 meanhotelsq4 meanmiscq4 meanotherexpq4 meanincomeq4 meanexpq4
  
; quintile 5 variables  
  totfoodq5 totalcoholq5 totclothingq5 tothousingq5 totfurnitureq5 tothealthq5 tottransportq5 totcommunicationq5  
  totrecreationq5 toteducq5 tothotelsq5 totmiscq5 tototherexpq5 totexpq5 totincomeq5
  meanfoodq5 meanalcoholq5 meanclothingq5 meanhousingq5 meanfurnitureq5 meanhealthq5 meantransportq5 meancommunicationq5
  meanrecreationq5 meaneducq5 meanhotelsq5 meanmiscq5 meanotherexpq5 meanincomeq5 meanexpq5
  
  meanfood meanalcohol meanclothing meanhousing meanfurniture meanhealth meantransport meancommunication
  emeanfood emeanalcohol emeanclothing emeanhousing emeanfurniture emeanhealth emeantransport emeancommunication  
  emeanfood2 emeanalcohol2 emeanclothing2 emeanhousing2 emeanfurniture2 emeanhealth2 emeantransport2 emeancommunication2
  emeanfood4 emeanalcohol4 emeanclothing4 emeanhousing4 emeanfurniture4 emeanhealth4 emeantransport4 emeancommunication4

  meanrecreation meaneduc meanhotels meanmisc meanotherexp meanincome
  emeanrecreation emeaneduc emeanhotels emeanmisc emeanotherexp emeanincome  
  emeanrecreation2 emeaneduc2 emeanhotels2 emeanmisc2 emeanotherexp2 emeanincome2
  emeanrecreation4 emeaneduc4 emeanhotels4 emeanmisc4 emeanotherexp4 emeanincome4
  pcincfood pcincalcohol pcincclothing pcinchousing pcincfurniture pcinchealth pcinctransport
  pcinccommunication pcincrecreation pcinceduc pcinchotels pcincmisc pcincotherexp
  pcincseconddwelling pcincinternet pcincsaved
  mean_population_income target_mean_population_income

  pcexpfood pcexpalcohol pcexpclothing pcexphousing pcexpfurniture pcexphealth pcexptransport
  pcexprecreation pcexpeduc pcexphotels pcexpmisc pcexpotherexp
  epcexpfood epcexpalcohol epcexpclothing epcexphousing epcexpfurniture epcexphealth epcexptransport
  epcexpcommunication epcexprecreation epcexpeduc epcexphotels epcexpmisc epcexpotherexp  
  epcexpfood2 epcexpalcohol2 epcexpclothing2 epcexphousing2 epcexpfurniture2 epcexphealth2 epcexptransport2
  epcexpcommunication2 epcexprecreation2 epcexpeduc2 epcexphotels2 epcexpmisc2 epcexpotherexp2
  epcexpfood4 epcexpalcohol4 epcexpclothing4 epcexphousing4 epcexpfurniture4 epcexphealth4 epcexptransport4
  epcexpcommunication4 epcexprecreation4 epcexpeduc4 epcexphotels4 epcexpmisc4 epcexpotherexp4

  pcsingle pcmarried pccohab pcseparated pcdivorced pcwidowed upper lower
  mm mms fm fms mcs fcs fc mc nmales nfem h1 h2 h3 h4 currentagent
  totincome totinternet meaninternet meanseconddwelling
  meantelecom meannontelecom toteffectiveincome
  tempsaved totsaved meansaved pcexpsaved
  etotincome etotexp2 etotexp4
  totexp etotexp totexp2 totexp4 etotincome2 etotincome4
  meanexp meanexp2 meanexp4 emeanexp emeanexp2 emeanexp4
  pclow pcmedium pchigh low medium high flow mflow fmed mfmed fhigh mfhigh pcother othergroup fother mfother
  type1pc type2pc type3pc type4pc type5pc type6pc    ; household type percentages
  q1 q2 q3 q4 changeeffective
  
  q2floor  ; second quartile household income boundaries
  q3floor  ; third quartile household income boundaries
  q4floor  ; highest quartile household income boundaries
  
  gtemptotalexpenditure   ; temporary variables for copying expenditures
  gtempinternet
  gtempseconddwelling
  gtempsaved
  gtempincanon
  gtemptelecom
  gtempnontelecom
  gtempeffectiveincome
  gtempfood
  gtempalcohol
  gtempclothing  
  gtemphousing
  gtempfurniture
  gtemphealth
  gtemptransport
  gtempcommunication  
  gtemprecreation
  gtempeduc
  gtemphotels
  gtempmisc
  gtempotherexp  
]

patches-own [
  pcase               ; patch address
  weight              ; household weight
  occupied            ; patch currently occupied
  currenttype         ; current household classification number
  lasttype            ; previous classification
  oldhhincome         ; household income last year
  males               ; number of males in household 
  females             ; number of females in household 
  food                ; spending on food
  fuel                ; spending on fuel
  young               ; number of under 30s
  midage              ; number aged 30 to 60
  old                 ; number over 60 
  housesize           ; number in house 
  axpmg               ; monthly mortgage
  aregion             ; region 
  ahstype             ; type of accommodation 
  ahsval              ; value of property
  arentg              ; gross rent
  totalexpenditure    ; total monthly household expenditure
  incanon             ; weekly household income
  quintile            ; income quintile
  hhincome            ; household income sum of individual incomes within household
  targetincome        ; income after annual change
  effectiveincome     ; incanon modified by change in energy costs
  oldeffectiveincome  ; previous effective income
  internet            ; weekly internet subscription
  communication       ; weekly communication expenditure
  seconddwelling      ; weekly expenditure on second home
  saved               ; weekly amount saved or invested
  nontelecom          ; not telecom related
  telecom             ; potential telecom recreationiture
  alcohol             ; weekly spending on alcohol & tabacco
  clothing            ; weekly expenditure on clothing & footwear
  housing             ; weekly spending on housing, water, electricity
  furniture           ; weekly furnishings & carpets
  health              ; weekly health costs
  transport           ; weekly transport costs
  recreation          ; weekly recreation expenditure
  educ                ; weekly education costs
  hotels              ; weekly expenditure on hotels & restaurants
  misc                ; miscelaneous expenditure
  otherexp            ; other expenditure
  deltaenergy         ; change in energy costs this year
  mortgage            ; mortgage interest payment
  nclass              ; ns-sec8 of HRP
  class               ; professional, intermediate, routine, other
  culture             ; most schooled household member
  changes_pending     ; household expenditures should be updated this year
  
  ptemptotalexpenditure   ; temporary variables for copying expenditures
  ptempclothing
  ptempinternet
  ptempcommunication
  ptempseconddwelling
  ptempsaved
  ptempincanon
  ptemptelecom
  ptempnontelecom
  ptempeffectiveincome
  ptempfood
  ptempalcohol
  ptemphousing
  ptempfurniture
  ptemphealth
  ptemptransport
  ptemprecreation
  ptempeduc
  ptemphotels
  ptempmisc
  ptempotherexp  
]

turtles-own [
  case           ; case number
  partnerid      ; who number of partner
  parentid       ; who number of parent
  person         ; household member number
  homex          ; x coordinate of original address
  homey          ; y coordinate of original address
  age            ; years
  under20        ; aged under 20
  twenties       ; aged in twenties
  thirties       ; aged in thirties
  forties        ; aged in forties
  fifties        ; aged in fifties
  sixties        ; aged 60 and over  
  sex            ; male female
  nsex           ; numerical sex read from file
  nstatus        ; numerical marrital status read from file
  status         ; married cohabiting single widowed divorced separated samesex
  previousstatus ; previous marital status
  newwidow       ; widowed in current mortality module
  newlyseparated ; 0 = no: number indicates time since separation in years
  children       ; number of children born by agent
  numdependents  ; number of agents responsible for
  newbirth       ; birth in current fertility module
  numinhouse     ; number of individuals in the household
  student        ; currently a full time student
  education      ; age completed full time education
  changed        ; recent change indicator
  newcohabit     ; cohabitation began in current year
  nemployment    ; numerical employment status from file
  employment     ; type of employment
  ajbhrs         ; hours worked per week
  asaved         ; amount saved each month
  apaygyr        ; gross earnings last 12 months
  ajbpl          ; work location
  ajbttwm        ; means of travel to work
  ajbttwt        ; minutes spent travelling to work
  neducation     ; age when left education secondaty, college, university
  parentsclass   ; ns-sec8 of hoh at birth
  myclass        ; current social class ns-sec8 
]

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; initialisation
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to setup
  clear-all
  init-patches
  initialise
  if apply_weights = true [
    applyhouseholdweights
  ]  
  findparents
  set years 0
  set mm 0
  set mms 0
  set fm 0
  set fms 0
  set changeeffective 1
  carefully [file-delete "outputmeans.dat"] []
  carefully [file-delete "outputq1means.dat"] []
  carefully [file-delete "outputq2means.dat"] []
  carefully [file-delete "outputq3means.dat"] []
  carefully [file-delete "outputq4means.dat"] []
  carefully [file-delete "outputq5means.dat"] []
      
  carefully [file-delete "outputpc.dat"] []  
 ; set change_in_energy_costs% 0
 
  carefully [file-delete "outputpc2.dat"] []
  carefully [file-delete "outputpc4.dat"] []
  
  set q2floor 273  ; initialise quartile household incomes
  set q3floor 485
  set q4floor 817
  
  clear_patches
  occupy_patches
  set_hrp_class
  set_culture
  set_scenareo                      ; set up parameters for running model
  initial_household_classification  ; set type of household based on demographics
  impute_income                     ; set income for cases with missing values
  initialise_temp_expenditures      ; avoid copying zero values when change_expenditures runs for the first time

  impute_expenditures               ; set expenditures for cases with missing expenditure data
  summarise
  assign_quintile
  outputexpenditures
  if write_to_file = true [
    writetofile
  ]  
  update-plot
  reset-ticks
end

to init-patches        ; read in household data
  let numhouses 0      ; house counter
  let lasthouse 0      ; highest house so far
  set currenthouse 0   ; number of current household
  ask patches [set pcase 0 set occupied 0]
  file-open "habitus_households1.dat"
  while [not file-at-end?] [
    set currenthouse file-read           ; household case id
      if currenthouse > lasthouse [
      set numhouses numhouses + 1
      if numhouses > households  [file-close stop]
      ask one-of patches with [pcase = 0] [
        set occupied 1
        set pcase currenthouse
        set housesize file-read          ; number in household a049
        set totalexpenditure file-read   ; total weekly household expenditure p630tp
        set internet file-read           ; internet subscription fees c94245
        set incanon file-read            ; weekly household income incanon
        set weight file-read             ; household weight weighta
        set nontelecom file-read         ; total recreation not telecom related
        set telecom file-read            ; total recteation expenditure telecom related
        set food file-read               ; total food p601t
        set alcohol file-read            ; total alcohol & tobacco p602t
        set clothing file-read           ; total clothing & footwear p603t
        set housing file-read            ; total housing, water, electricity p604t
        set furniture file-read          ; total furniture, carpets etc. p605t
        set health file-read             ; total health p606t
        set transport file-read          ; total transport p607t
        set communication file-read      ; total communication p608t
        set recreation file-read         ; total recreation p609t
        set educ file-read               ; total education p610t
        set hotels file-read             ; total hotels & restaurants p611t
        set misc file-read               ; miscelaneous p612t
        set mortgage file-read           ; monthly mortgage payment
        set nclass file-read             ; ns-sec8 of HRP
        
        if housesize < 0 [set housesize 0]        ; allow for missing data
        if totalexpenditure < 0 [set totalexpenditure 0]
        if internet < 0 [set internet 0]
        if incanon < 0 [set incanon 0]
        if incanon = 0 [set weight 0]
        if food < Min_Food [set food Min_Food]
        if alcohol < 0 [set alcohol 0]        
        if clothing < 0 [set clothing 0]
        if housing < 0 [set housing 0]
        if furniture < 0 [set furniture 0]
        if health < 0 [set health 0]
        if transport < 0 [set transport 0]
        if communication < 0 [set communication 0]
        if recreation < 0 [set recreation 0]
        if educ < 0 [set educ 0]
        if hotels < 0 [set hotels 0]
        if misc < 0 [set misc 0]
        ;if weight >= 5 [set weight 5]  ; cap efs household weight at 5
        set effectiveincome incanon
        if effectiveincome < 10 [set effectiveincome 10]
        set oldhhincome incanon
        set oldeffectiveincome incanon
        set otherexp totalexpenditure - (food + alcohol + clothing + housing + furniture + health + transport + communication + recreation + educ + hotels + misc)
        if mortgage < 0 [set mortgage 0]
        if nclass <= 0 [set nclass 0 set class "other"]
        
        if nclass = 1 or nclass = 2 or nclass = 3 [set class "professional"]
        if nclass = 4 or nclass = 5 or nclass = 6 or nclass = 7 [set class "intermediate"]
        if nclass = 8 or nclass = 9 or nclass = 10 [set class "routine"]
        if nclass >= 11 [set class "other"]
      ]
      set lasthouse currenthouse
    ]  
  ]
  file-close
  show "finished reading household file"
end

to initialise  ; set up initial agent population
  let r 0.0
  let recnum 0
  let finished 0
  set maxhouseholds max [pcase] of patches
  file-open "PO1ind1.dat"
  while [not file-at-end? and finished = 0] [
    set recnum file-read
    if-else recnum <= maxhouseholds [
      cro 1 [                     ; create a new agent
        set case recnum           ; set turtle identifier from file
        set currentcase case      ; set current case number
        set person file-read      ; household person index number 
        set age file-read         ; age
        set nsex file-read        ; gender code number
        set nstatus file-read     ; marital status code number
        set student file-read     ; currently a full time student
        set neducation file-read  ; age completed full time education

        setagebands  ; initialise or update age bands according to current age
        
        if nsex = 1 [set sex "male" set color blue]
        if nsex = 2 [set sex "female" set color pink]
      
        if nstatus <= 0 [set status "single"]
        if nstatus = 1 [set status "married"]
        if nstatus = 2 [set status "cohabiting"]
        if nstatus = 3 [set status "single"]
        if nstatus = 4 [set status "widowed"]
        if nstatus = 5 [set status "divorced"]
        if nstatus = 6 [set status "separated"]
        if nstatus = 7 [set status "same sex couple"]
        if nstatus = 8 [set status "civil partnership"]
        if nstatus >= 9 [set status "single"]
        
        set previousstatus "single"
        if status = "separated" [set previousstatus "married"]
        if status = "widowed" [set previousstatus "married"]
        if status = "divorced" [set previousstatus "separated"]
        
        set student 0
        if age <= 16 [set student 1]
        
        ifelse any? patches with [pcase = currentcase] [
          move-to one-of patches with [pcase = currentcase]  ; go to the family address
          set homex pxcor          ; initialise original address
          set homey pycor          ; initialise original address
          ; show nclass
          set parentsclass nclass  ; initialise class of origin
          set myclass parentsclass ; initialise agent's class
          if student = 1 [set myclass 10]         
        ]
        [show "patch not found" die]
      ]
    ]    
    [set finished 1]
  ]
  file-close
  show "finished reading agent file"
end

to applyhouseholdweights
  let r 0.0
  let w 0.0

  ask patches with [count turtles-here > 0] [
    set r random-float 1
    if weight = 0 [delete_household]        ; ignore households with zero weight
    if weight < 1 [if r >= weight [delete_household]]  ; select households according to probability derived from weight
    ; if weight = 1 do nothing
    set w weight
    while [w >= 2] [
      store_expenditures
      copy_household
      copy_turtles
      set w w - 1
    ]
    if r < (w - 1) [store_expenditures copy_household copy_turtles]
  ]
  show "weights applied"
end

to clear_patches
  ask patches with [count turtles-here = 0] [clear_patch]
end

to occupy_patches
  ask patches with [count turtles-here > 0] [set occupied 1]
  ; show count patches with [occupied = 1]  
end

to clear_patch
  set occupied 0
  set pcase 0
end

to delete_household
  ask turtles-here [die]
  clear_patch
end

to copy_household
  set currenthouse currenthouse + 1
  ask one-of patches with [pcase = 0] [
    read_expenditures
    set pcase currenthouse
    set occupied 1
  ]
end

to copy_turtles
  ask turtles-here [
    hatch 1 [
      set color white
      move-to one-of patches with [pcase = currenthouse]
      set homex pxcor          ; initialise original address
      set homey pycor          ; initialise original address      
    ]
  ]
end

to findparents          ; record id of parent
  let tempid 0
  let tempage 0
  let r 0.0
  set r random-float 1
  
  if r < 0.9 [                                              ; female is responsible for children
    ask patches with [count turtles-here > 0] [             ; for each household
      ask turtles-here [                                    ; for each occupant
        set tempid 0
        set tempage age
        if any? turtles-here with [sex = "female" and age > tempage + 16 and age < tempage + 40]        ; identify female parent
        [
          ask one-of turtles-here with [sex = "female" and age > tempage + 16 and age < tempage + 40] [set tempid who]  ; get parents id
        ]  
        set parentid tempid  ; remember parents id
      ]
    ]
  ]
  
  if r >= 0.9 [                                            ; male is responsible for children
    ask patches with [count turtles-here > 0] [            ; for each household
      ask turtles-here [                                   ; for each occupant
        set tempid 0
        set tempage age
        if any? turtles-here with [sex = "male" and age > tempage + 16 and age < tempage + 40]        ; identify male parent
        [
        ask one-of turtles-here with [sex = "male" and age > tempage + 16 and age < tempage + 40] [set tempid who]  ; get parents id
        ]  
        set parentid tempid  ; remember parents id
      ]    
    ]
  ]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;control routines
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to go                          ; main loop
  if years = stop_after [stop]
  set years years + 1  ; increment calender
  clear_patches                ; mark empty patches as unoccupied
  occupy_patches               ; mark occupied households
  set_hrp_class
  set_culture
  set mean_population_income mean [incanon] of patches with [occupied = 1]
  set target_mean_population_income mean_population_income + mean_population_income * (change_in_real_income% / 100)

  ask patches [
    if any? turtles-here [
      calculateexpenditures    ; find new expenditures 
    ]
  ]
  set changeeffective 1
  update_expenditures          ; detect changed household income and update expenditures from another patch of the same demographic type
  change_expenditures
  summarise
  assign_quintile
  outputexpenditures
  if write_to_file = true [
    writetofile
  ]  
  update-plot
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; expenditure modules
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to initial_household_classification                          ; assign initial household type based on demographic parameters only
  ask patches with [count turtles-here > 0] [
    set lasttype currenttype
    set currenttype 6  ; other households
    
    if count turtles-here = 1 and count turtles-here with [sex = "male"] = 1 and
      max[age] of turtles-here < 65 [set currenttype 1]                                      ; single non pensionable
    if count turtles-here = 1 and count turtles-here with [sex = "female"] = 1 and
      max[age] of turtles-here < 60 [set currenttype 1]                                      ; single non pensionable

    if max [age] of turtles-here > 65 [set currenttype 2]                                    ; headed by over 65
    ;if count turtles-here >= 1 and count turtles-here with [sex = "male"] = 1 and
    ;  min[age] of turtles-here > 65 [set currenttype 2]                                     ; over 65
    ;if count turtles-here >= 1 and count turtles-here with [sex = "female"] = 1 and
    ;   min[age] of turtles-here > 65 [set currenttype 2]                                    ; over 65
      
    if count turtles-here = 2 and count turtles-here with [age < 16] = 0 [set currenttype 3] ; 2 adults
    
    let nk 0
    set nk count turtles-here with [age < 5] ; count under 5s
    if nk >= 1 and count turtles-here with [age >= 18] >= 1 [set currenttype 4]                           ; children under 5
    ;set nk 0
    ;set nk count turtles-here with [age < 5] ; count under 5s
    ;if nk >= 1 and count turtles-here with [age >= 18] >= 1 [set currenttype 4]                           ; children under 5
  ]    
end

to impute_income
  let t 0                                                                        ; choose a random income for households with no stated income
  ask patches with ([count turtles-here >= 1 and incanon <= 0]) [
    set t currenttype
    set incanon [incanon] of one-of patches with [incanon > 0 and currenttype = t]
  ]
end

to impute_expenditures
  let t 0
  ask patches with ([count turtles-here >= 1 and food < 0]) [
    set t currenttype
    ask one-of patches with [currenttype = t] [store_expenditures]
    read_expenditures
  ]
end

to set_hrp_class                            ; reset the household class to the highest class of all occupants
  ask patches with [occupied = 1] [
    if any? turtles-here with [myclass = 0] [set class "other"]
    if any? turtles-here with [myclass >= 11 and myclass <= 12] [set class "other"]
    if any? turtles-here with [myclass >= 8 and myclass <= 10] [set class "routine"]
    if any? turtles-here with [myclass >= 4 and myclass <= 7] [set class "intermediate"]
    if any? turtles-here with [myclass >= 1 and myclass <= 3] [set class "professional"]
  ]  
end

to set_culture                              ; estimate household cultural capital from educational level of occupants 
  let ageleftfulltimeeducation 0
  ask patches with [occupied = 1] [
    set ageleftfulltimeeducation max [neducation] of turtles-here
    if ageleftfulltimeeducation <= 16 [set culture "secondary"]
    if ageleftfulltimeeducation >= 17 and ageleftfulltimeeducation <= 18 [set culture "intermediate"]
    if ageleftfulltimeeducation >= 21 [set culture "university"]
  ]
end  

to calculateexpenditures                    ; update expenditure determinants for each patch
  set oldhhincome incanon
  set changes_pending false
  set targetincome incanon + incanon * (change_in_real_income% / 100)
  if oldhhincome < 0 [show "error"]
  set hhincome sum [apaygyr] of turtles-here
end

to change_energy_prices      ; calculate effect of changed energy costs
  ask patches with [occupied = 1] [
    set deltaenergy 0
    set oldeffectiveincome effectiveincome
  ]
end

to update_expenditures    ; if state transition copy expenditures from another patch
  let t 0              ; household type
  let targ 0.0         ; household income after change
  let r 0.0            ; random number
  let copytype 0       ; type of household to copy from
  let cul 0            ; highest educational level in household
  let sec 0            ; class of hrp
  let h 0              ; household size
  let limit 0          ; maximum allowed difference in donor income
  let keepgoing false  ; more households to process
  
  ask patches with [occupied = 1] [
    set keepgoing true
    set mean_population_income mean [ptempincanon] of patches with [occupied = 1]
    if change_in_real_income% > 0 [
      if mean_population_income < target_mean_population_income [set keepgoing true]
    ]
    if change_in_real_income% < 0 [
      if mean_population_income > target_mean_population_income [set keepgoing true]  
    ]
    if incanon != targetincome and keepgoing = true [
      set t currenttype
      set targ targetincome
      set sec class
      set cul culture
      set h count turtles-here
      set r random-float 1
      set limit incanon * (2 * change_in_real_income% / 100) ; limit income change of donor to twice intended income change
      ;show "------"
      ;show incanon
      ;show limit
      ;show "------"

      set copytype 0
      if r > 0.5 [        ; copy from next higher income household
        if any? other patches with [incanon >= targ and incanon <= targ + limit and occupied = 1] [set copytype 1]
        if any? other patches with [currenttype = t and incanon >= targ and incanon <= targ + limit and occupied = 1] [set copytype 2]
        if any? other patches with [currenttype = t and incanon >= targ and incanon <= targ + limit and occupied = 1 and
          count turtles-here = h] [set copytype 3]

        if copytype = 1 [
          vary_expenditures
        ]                          
        if copytype = 2 [
         vary_expenditures
        ]
        if copytype = 3 [
          ask min-one-of other patches with [currenttype = t and incanon >= targ and incanon <= targ + limit and occupied = 1 and
            count turtles-here = h] [incanon] [store_expenditures]
          read_temp_expenditures
        ]
        if copytype = 0 [
          vary_expenditures    ; if there is no suitable household to copy from then change income end expenditures in proportion
        ] ; show "higher income copied type" show copytype
      ]
      if r <= 0.5 [             ; copy from next lower income household
        if any? other patches with [incanon <= targ and incanon >= targ - limit and occupied = 1] [set copytype 1]
        if any? other patches with [currenttype = t and incanon <= targ and incanon >= targ - limit and occupied = 1] [set copytype 2]
        if any? other patches with [currenttype = t and incanon <= targ and incanon >= targ - limit and occupied = 1 and
          count turtles-here = h] [set copytype 3]
        
        if copytype = 1 [
          vary_expenditures
        ]
        if copytype = 2 [
          vary_expenditures
        ]
        if copytype = 3 [
          ask max-one-of other patches with [currenttype = t and incanon <= targ and incanon >= targ - limit and occupied = 1 and
            count turtles-here = h] [incanon] [store_expenditures]
          read_temp_expenditures
        ]
        if copytype = 0 [
          vary_expenditures    ; if there is no suitable household to copy from then change income end expenditures in proportion
        ] ; show "lower income copied type" show copytype
      ]
    ]
  ]
end

to vary_effective  ; inflate or deflate all expenditures when there is no suitable household to copy from
  if oldeffectiveincome != 0 [
    set ptemptotalexpenditure totalexpenditure - (totalexpenditure * ((oldeffectiveincome - effectiveincome) / oldeffectiveincome))
    set ptempinternet internet - (internet * ((oldeffectiveincome - effectiveincome) / oldeffectiveincome))
    set ptempsaved saved - (saved * ((oldeffectiveincome - effectiveincome) / oldeffectiveincome))
    set ptemptelecom telecom - (telecom * ((oldeffectiveincome - effectiveincome) / oldeffectiveincome))
    set ptempnontelecom nontelecom - (nontelecom * ((oldeffectiveincome - effectiveincome) / oldeffectiveincome))
    set ptempfood food - (food * ((oldeffectiveincome - effectiveincome) / oldeffectiveincome))
    set ptempalcohol alcohol - (alcohol * ((oldeffectiveincome - effectiveincome) / oldeffectiveincome))
    set ptempclothing clothing - (clothing * ((oldeffectiveincome - effectiveincome) / oldeffectiveincome))
    set ptemphousing housing - (housing * ((oldeffectiveincome - effectiveincome) / oldeffectiveincome))
    set ptempfurniture furniture - (furniture * ((oldeffectiveincome - effectiveincome) / oldeffectiveincome))
    set ptemphealth health - (health * ((oldeffectiveincome - effectiveincome) / oldeffectiveincome))
    set ptemptransport transport - (transport * ((oldeffectiveincome - effectiveincome) / oldeffectiveincome))
    set ptempcommunication communication - (communication * ((oldeffectiveincome - effectiveincome) / oldeffectiveincome))
    set ptemprecreation recreation - (recreation * ((oldeffectiveincome - effectiveincome) / oldeffectiveincome))
    set ptempeduc educ - (educ * ((oldeffectiveincome - effectiveincome) / oldeffectiveincome))
    set ptemphotels hotels - (hotels * ((oldeffectiveincome - effectiveincome) / oldeffectiveincome))
    set ptempmisc misc - (misc * ((oldeffectiveincome - effectiveincome) / oldeffectiveincome))
    set ptempotherexp otherexp - (otherexp * ((oldeffectiveincome - effectiveincome) / oldeffectiveincome))
  ]  
end

to vary_expenditures  ; inflate or deflate all expenditures when there is no higher or lower income household to copy from
  if incanon != 0 [
    set changes_pending true
    set ptempincanon incanon - (incanon * ((incanon - targetincome) / incanon))
    set ptempeffectiveincome effectiveincome - (effectiveincome * ((incanon - targetincome) / incanon))
    set ptemptotalexpenditure totalexpenditure - (totalexpenditure * ((incanon - targetincome) / incanon))
    set ptempinternet internet - (internet * ((incanon - targetincome) / incanon))
    set ptempsaved saved - (saved * ((incanon - targetincome) / incanon))
    set ptemptelecom telecom - (telecom * ((incanon - targetincome) / incanon))
    set ptempnontelecom nontelecom - (nontelecom * ((incanon - targetincome) / incanon))
    set ptempfood food - (food * ((incanon - targetincome) / incanon))
    set ptempalcohol alcohol - (alcohol * ((incanon - targetincome) / incanon))
    set ptempclothing clothing - (clothing * ((incanon - targetincome) / incanon))
    set ptemphousing housing - (housing * ((incanon - targetincome) / incanon))
    set ptempfurniture furniture - (furniture * ((incanon - targetincome) / incanon))
    set ptemphealth health - (health * ((incanon - targetincome) / incanon))
    set ptemptransport transport - (transport * ((incanon - targetincome) / incanon))
    set ptempcommunication communication - ((communication * (incanon - targetincome) / incanon))
    set ptemprecreation recreation - (recreation * ((incanon - targetincome) / incanon))
    set ptempeduc educ - (educ * ((incanon - targetincome) / incanon))
    set ptemphotels hotels - (hotels * ((incanon - targetincome) / incanon))
    set ptempmisc misc - (misc * ((incanon - targetincome) / incanon))
    set ptempotherexp otherexp - (otherexp * ((incanon - targetincome) / incanon))
    
    
    ; adjust expenditures if food spending goes below threshold
    if Min_Food > 0 [
    let newtot 0
    let shortfall 0
    let proportion 0

    set shortfall Min_Food - ptempfood
    if shortfall > 0 [
      set newtot ptempfood + ptempalcohol + ptempclothing + ptemphousing + ptempfurniture + ptemphealth +
                    ptemptransport + ptempcommunication + ptemprecreation + ptempeduc + ptemphotels + ptempmisc + ptempotherexp
      set proportion shortfall / newtot
    
      set ptempfood ptempfood + shortfall
    
      set ptempalcohol ptempalcohol - (proportion * ptempalcohol)
      set ptempclothing ptempclothing - (proportion * ptempclothing)    
      set ptemphousing ptemphousing - (proportion * ptemphousing)
      set ptempfurniture ptempfurniture - (proportion * ptempfurniture)
      set ptemphealth ptemphealth - (proportion * ptemphealth)  
      set ptemptransport ptemptransport - (proportion * ptemptransport)
      set ptempcommunication ptempcommunication - (proportion * ptempcommunication)   
      set ptemprecreation ptemprecreation - (proportion * ptemprecreation)
      set ptempeduc ptempeduc - (proportion * ptempeduc)
      set ptemphotels ptemphotels - (proportion * ptemphotels)    
      set ptempmisc ptempmisc - (proportion * ptempmisc)
      set ptempotherexp ptempotherexp - (proportion * ptempotherexp)
      ;set ptemptotalexpenditure ptemptotalexpenditure - (proportion * ptemptotalexpenditure)
      show "redistributing"
    ]
    
    ; adjust expenditures if total expenditure is greater than income by reducing expenditures other than food
    let newtotalexpenditure 0
    let incomeshortfall 0
    let incomeproportion 0

    set newtotalexpenditure ptempfood + ptempalcohol + ptempclothing + ptemphousing + ptempfurniture + ptemphealth +
                  ptemptransport + ptempcommunication + ptemprecreation + ptempeduc + ptemphotels + ptempmisc + ptempotherexp

    set incomeshortfall totalexpenditure - incanon
    if incomeshortfall > 0 [
      set incomeproportion incomeshortfall / totalexpenditure
      show "reducing expenditures"
      show "proportion"
      show incomeproportion
      show "incanon"
      show incanon
      show "totalexpenditure"
      show totalexpenditure
      set ptempalcohol ptempalcohol - (incomeproportion * ptempalcohol)
      set ptempclothing ptempclothing - (incomeproportion * ptempclothing)    
      set ptemphousing ptemphousing - (incomeproportion * ptemphousing)
      set ptempfurniture ptempfurniture - (incomeproportion * ptempfurniture)
      set ptemphealth ptemphealth - (incomeproportion * ptemphealth)  
      set ptemptransport ptemptransport - (incomeproportion * ptemptransport)
      set ptempcommunication ptempcommunication - (incomeproportion * ptempcommunication)   
      set ptemprecreation ptemprecreation - (incomeproportion * ptemprecreation)
      set ptempeduc ptempeduc - (incomeproportion * ptempeduc)
      set ptemphotels ptemphotels - (incomeproportion * ptemphotels)    
      set ptempmisc ptempmisc - (incomeproportion * ptempmisc)
      set ptempotherexp ptempotherexp - (incomeproportion * ptempotherexp)
      set ptemptotalexpenditure ptemptotalexpenditure - (incomeproportion * ptemptotalexpenditure)
    ]
    ]
  ]  
end

to recalibrate              ; change imported budget shares to fit with change in energy prices
  ask patches with [occupied = 1 and oldeffectiveincome != 0] [
    set totalexpenditure totalexpenditure + (totalexpenditure * ((oldeffectiveincome - effectiveincome) / oldeffectiveincome))
    set internet internet + (internet * ((oldeffectiveincome - effectiveincome) / oldeffectiveincome))
    set saved saved + (saved * ((oldeffectiveincome - effectiveincome) / oldeffectiveincome))
    set telecom telecom + (telecom * ((oldeffectiveincome - effectiveincome) / oldeffectiveincome))
    set nontelecom nontelecom + (nontelecom * ((oldeffectiveincome - effectiveincome) / oldeffectiveincome))
    set food food + (food * ((oldeffectiveincome - effectiveincome) / oldeffectiveincome))
    set alcohol alcohol + (alcohol * ((oldeffectiveincome - effectiveincome) / oldeffectiveincome))
    set clothing clothing + (clothing * ((oldeffectiveincome - effectiveincome) / oldeffectiveincome))
    set housing housing + (housing * ((oldeffectiveincome - effectiveincome) / oldeffectiveincome))
    set furniture furniture + (furniture * ((oldeffectiveincome - effectiveincome) / oldeffectiveincome))
    set health health + (health * ((oldeffectiveincome - effectiveincome) / oldeffectiveincome))
    set transport transport + (transport * ((oldeffectiveincome - effectiveincome) / oldeffectiveincome))
    set communication communication + (communication * ((oldeffectiveincome - effectiveincome) / oldeffectiveincome))
    set recreation recreation + (recreation * ((oldeffectiveincome - effectiveincome) / oldeffectiveincome))
    set educ educ + (educ * ((oldeffectiveincome - effectiveincome) / oldeffectiveincome))
    set hotels hotels + (hotels * ((oldeffectiveincome - effectiveincome) / oldeffectiveincome))
    set misc misc + (misc * ((oldeffectiveincome - effectiveincome) / oldeffectiveincome))
    set otherexp otherexp + (otherexp * ((oldeffectiveincome - effectiveincome) / oldeffectiveincome))
  ]
end

to store_expenditures    ; record expenditures in global variables for copying to another patch
  set gtempincanon incanon
  set gtemptotalexpenditure totalexpenditure
  set gtempinternet internet
  set gtempsaved saved
  set gtemptelecom telecom
  set gtempnontelecom nontelecom
  set gtempeffectiveincome effectiveincome
  set gtempfood food
  set gtempalcohol alcohol
  set gtempclothing clothing
  set gtemphousing housing
  set gtempfurniture furniture
  set gtemphealth health
  set gtemptransport transport
  set gtempcommunication communication
  set gtemprecreation recreation
  set gtempeduc educ
  set gtemphotels hotels
  set gtempmisc misc
  set gtempotherexp otherexp
end

to read_temp_expenditures    ; read stored global budget shares into current patch temporary variables
  set changes_pending true
  set ptempincanon gtempincanon
  set ptemptotalexpenditure gtemptotalexpenditure
  set ptempinternet gtempinternet
  set ptempsaved gtempsaved
  set ptemptelecom gtemptelecom
  set ptempnontelecom gtempnontelecom
  set ptempeffectiveincome gtempeffectiveincome
  set ptempfood gtempfood
  set ptempalcohol gtempalcohol
  set ptempclothing gtempclothing
  set ptemphousing gtemphousing
  set ptempfurniture gtempfurniture
  set ptemphealth gtemphealth
  set ptemptransport gtemptransport
  set ptempcommunication gtempcommunication
  set ptemprecreation gtemprecreation
  set ptempeduc gtempeduc
  set ptemphotels gtemphotels
  set ptempmisc gtempmisc
  set ptempotherexp gtempotherexp
end

to read_expenditures    ; alter expenditures directly from global variable
  set totalexpenditure gtemptotalexpenditure
  set internet gtempinternet
  set incanon gtempincanon
  set saved gtempsaved
  set telecom gtemptelecom
  set nontelecom gtempnontelecom
  set effectiveincome gtempeffectiveincome
  set food gtempfood
  set alcohol gtempalcohol
  set clothing gtempclothing
  set housing gtemphousing
  set furniture gtempfurniture
  set health gtemphealth
  set transport gtemptransport
  set communication gtempcommunication
  set recreation gtemprecreation
  set educ gtempeduc
  set hotels gtemphotels
  set misc gtempmisc
  set otherexp gtempotherexp
end

to change_expenditures    ; alter expenditures from temporary patch variables after annual processing is completed
  ask patches with [occupied = 1 and changes_pending = true] [
    set incanon ptempincanon
    set totalexpenditure ptemptotalexpenditure
    set internet ptempinternet
    set saved ptempsaved
    set telecom ptemptelecom
    set nontelecom ptempnontelecom
    set effectiveincome ptempeffectiveincome
    set food ptempfood
    set alcohol ptempalcohol
    set clothing ptempclothing
    set housing ptemphousing
    set furniture ptempfurniture
    set health ptemphealth
    set transport ptemptransport
    set communication ptempcommunication
    set recreation ptemprecreation
    set educ ptempeduc
    set hotels ptemphotels
    set misc ptempmisc
    set otherexp ptempotherexp
  ]
end

to initialise_temp_expenditures    ; set up initial values in temporary patch variables
  ask patches with [occupied = 1] [
    set ptemptotalexpenditure totalexpenditure
    set ptempinternet internet
    set ptempincanon incanon
    set ptempsaved saved
    set ptemptelecom telecom
    set ptempnontelecom nontelecom
    set ptempeffectiveincome effectiveincome
    set ptempfood food
    set ptempalcohol alcohol
    set ptempclothing clothing
    set ptemphousing housing
    set ptempfurniture furniture
    set ptemphealth health
    set ptemptransport transport
    set ptempcommunication communication
    set ptemprecreation recreation
    set ptempeduc educ
    set ptemphotels hotels
    set ptempmisc misc
    set ptempotherexp otherexp
  ]  
end

to assign_quintile
  set houses count patches with [count turtles-here > 0]
  let n 1
  let quintilesize 0
  set quintilesize (houses / 5)
  foreach sort-on [incanon / sqrt(housesize)] patches with [count turtles-here > 0] [
    ask ? [
      if n <= quintilesize [
        set quintile 1
      ]  
      if n > quintilesize and n <= quintilesize * 2 [
        set quintile 2
      ]  
      if n > quintilesize * 2 and n <= quintilesize * 3 [
        set quintile 3  
      ]
      if n > quintilesize * 3 and n <= quintilesize * 4 [
        set quintile 4
      ]
      if n > quintilesize * 4 [
        set quintile 5
      ]
      set n n + 1
    ]  
  ]  
end

to summarise                    ; set up global variables after annual cycle
  set pop count turtles
  if pop = 0 [stop]
  ask patches [set housesize count turtles-here]
  set houses count patches with [count turtles-here > 0]
  set h1 count patches with [count turtles-here = 1]
  set h1 (h1 / houses) * 100
  set h2 count patches with [count turtles-here = 2]
  set h2 (h2 / houses) * 100
  set h3 count patches with [count turtles-here = 3]
  set h3 (h3 / houses) * 100
  set h4 count patches with [count turtles-here >= 4]
  set h4 (h4 / houses) * 100
  set hsize (pop / houses)
  set nmales count turtles with [sex = "male"]
  set nfem count turtles with [sex = "female"]
  set pcsingle count turtles with [status = "single"]
  set pcsingle (pcsingle / pop) * 100
  set pccohab count turtles with [status = "cohabiting"]
  set pccohab (pccohab / pop) * 100
  set pcmarried count turtles with [status = "married"]
  set pcmarried (pcmarried / pop) * 100
  set pcseparated count turtles with [status = "separated"]
  set pcseparated (pcseparated / pop) * 100
  set pcdivorced count turtles with [status = "divorced"]
  set pcdivorced (pcdivorced / pop) * 100  
  set pcwidowed count turtles with [status = "widowed"]
  set pcwidowed (pcwidowed / pop) * 100  
end

to outputexpenditures                                  ; set up expenditures ready for plotting
  set houses count patches with [count turtles-here > 0]
  set houses2 count patches with [count turtles-here > 0 and currenttype = 2]  
  set houses4 count patches with [count turtles-here > 0 and currenttype = 4]
  set totexp sum [totalexpenditure] of patches with [occupied = 1]
  set etotexp sum [totalexpenditure / sqrt(housesize)] of patches with [occupied = 1]  
  set etotexp2 sum [totalexpenditure / sqrt(housesize)] of patches with [occupied = 1 and currenttype = 2]  
  set etotexp4 sum [totalexpenditure / sqrt(housesize)] of patches with [occupied = 1 and currenttype = 4]

  set totseconddwelling sum [seconddwelling] of patches with [occupied = 1]
  set totincome sum [incanon] of patches with [occupied = 1]
  set totincome2 sum [incanon] of patches with [occupied = 1 and currenttype = 2]
  set totincome4 sum [incanon] of patches with [occupied = 1 and currenttype = 4]
  
  set totoldhhincome sum [oldhhincome] of patches with [occupied = 1]
  set toteffectiveincome sum [effectiveincome] of patches with [occupied = 1]
  
  set totfood sum [food] of patches with [occupied = 1]
  set totalcohol sum [alcohol] of patches with [occupied = 1]
  set totclothing sum [clothing] of patches with [occupied = 1]
  set tothousing sum [housing] of patches with [occupied = 1]
  set totfurniture sum [furniture] of patches with [occupied = 1]
  set tothealth sum [health] of patches with [occupied = 1]
  set tottransport sum [transport] of patches with [occupied = 1]
  set totcommunication sum [communication] of patches with [occupied = 1]
  set totrecreation sum [recreation] of patches with [occupied = 1]  
  set toteduc sum [educ] of patches with [occupied = 1]  
  set tothotels sum [hotels] of patches with [occupied = 1]  
  set totmisc sum [misc] of patches with [occupied = 1]  
  set tototherexp sum [otherexp] of patches with [occupied = 1]
   
  set etotfood sum [food / sqrt(housesize)] of patches with [occupied = 1]
  set etotalcohol sum [alcohol / sqrt(housesize)] of patches with [occupied = 1]
  set etotclothing sum [clothing / sqrt(housesize)] of patches with [occupied = 1]
  set etothousing sum [housing / sqrt(housesize)] of patches with [occupied = 1]
  set etotfurniture sum [furniture / sqrt(housesize)] of patches with [occupied = 1]
  set etothealth sum [health / sqrt(housesize)] of patches with [occupied = 1]
  set etottransport sum [transport / sqrt(housesize)] of patches with [occupied = 1]
  set etotcommunication sum [communication / sqrt(housesize)] of patches with [occupied = 1]
  set etotrecreation sum [recreation / sqrt(housesize)] of patches with [occupied = 1]  
  set etoteduc sum [educ / sqrt(housesize)] of patches with [occupied = 1]  
  set etothotels sum [hotels / sqrt(housesize)] of patches with [occupied = 1]  
  set etotmisc sum [misc / sqrt(housesize)] of patches with [occupied = 1]  
  set etototherexp sum [otherexp / sqrt(housesize)] of patches with [occupied = 1] 
  
  set totinternet sum [internet] of patches with [occupied = 1]
  set totseconddwelling sum [seconddwelling] of patches with [occupied = 1]
  set totsaved sum [saved] of patches with [occupied = 1]
  set tottelecom sum [telecom] of patches with [occupied = 1]
  set totnontelecom sum [nontelecom] of patches with [occupied = 1]
  
  set meanincome precision (totincome / houses) 2
  set meanexp precision (totexp / houses) 2
  set meanfood precision (totfood / houses) 2
  set meanalcohol precision (totalcohol / houses) 2
  set meanclothing precision (totclothing / houses) 2  
  set meanhousing precision (tothousing / houses) 2
  set meanfurniture precision (totfurniture / houses) 2
  set meanhealth precision (tothealth / houses) 2
  set meantransport precision (tottransport / houses) 2
  set meancommunication precision (totcommunication / houses) 2
  set meanrecreation precision (totrecreation / houses) 2
  set meaneduc precision (toteduc / houses) 2
  set meanhotels precision (tothotels / houses) 2
  set meanmisc precision (totmisc / houses) 2
  set meanotherexp precision (tototherexp / houses) 2  

  set emeanincome precision (etotincome / houses) 2
  set emeanexp precision (etotexp / houses) 2
  set emeanfood precision (etotfood / houses) 2
  set emeanalcohol precision (etotalcohol / houses) 2
  set emeanclothing precision (etotclothing / houses) 2  
  set emeanhousing precision (etothousing / houses) 2
  set emeanfurniture precision (etotfurniture / houses) 2
  set emeanhealth precision (etothealth / houses) 2
  set emeantransport precision (etottransport / houses) 2
  set emeancommunication precision (etotcommunication / houses) 2
  set emeanrecreation precision (etotrecreation / houses) 2
  set emeaneduc precision (etoteduc / houses) 2
  set emeanhotels precision (etothotels / houses) 2
  set emeanmisc precision (etotmisc / houses) 2
  set emeanotherexp precision (etototherexp / houses) 2

; quintile 1 means
  set housesq1 count patches with [occupied = 1 and quintile = 1] 
  set meanexpq1 precision mean [totexp / sqrt(housesize)] of patches with [occupied = 1 and quintile = 1] 2
  set meanincomeq1 precision mean [incanon / sqrt(housesize)] of patches with [occupied = 1 and quintile = 1] 2
  set meanfoodq1 precision mean [food / sqrt(housesize)] of patches with [occupied = 1 and quintile = 1] 2
  set meanalcoholq1 precision mean [alcohol / sqrt(housesize)] of patches with [occupied = 1 and quintile = 1] 2
  set meanclothingq1 precision mean [clothing / sqrt(housesize)] of patches with [occupied = 1 and quintile = 1] 2
  set meanhousingq1 precision mean [housing / sqrt(housesize)] of patches with [occupied = 1 and quintile = 1] 2
  set meanfurnitureq1 precision mean [furniture / sqrt(housesize)] of patches with [occupied = 1 and quintile = 1] 2
  set meanhealthq1 precision mean [health / sqrt(housesize)] of patches with [occupied = 1 and quintile = 1] 2
  set meantransportq1 precision mean [transport / sqrt(housesize)] of patches with [occupied = 1 and quintile = 1] 2
  set meancommunicationq1 precision mean [communication / sqrt(housesize)] of patches with [occupied = 1 and quintile = 1] 2
  set meanrecreationq1 precision mean [recreation / sqrt(housesize)] of patches with [occupied = 1 and quintile = 1] 2
  set meaneducq1 precision mean [educ / sqrt(housesize)] of patches with [occupied = 1 and quintile = 1] 2
  set meanhotelsq1 precision mean [hotels / sqrt(housesize)] of patches with [occupied = 1 and quintile = 1] 2
  set meanmiscq1 precision mean [misc / sqrt(housesize)] of patches with [occupied = 1 and quintile = 1] 2
  set meanotherexpq1 precision mean [otherexp / sqrt(housesize)] of patches with [occupied = 1 and quintile = 1] 2
   
; quintile2 means
  set housesq2 count patches with [occupied = 1 and quintile = 2]
  set meanexpq2 precision mean [totexp / sqrt(housesize)] of patches with [occupied = 1 and quintile = 2] 2
  set meanincomeq2 precision mean [incanon / sqrt(housesize)] of patches with [occupied = 1 and quintile = 2] 2
  set meanfoodq2 precision mean [food / sqrt(housesize)] of patches with [occupied = 1 and quintile = 2] 2
  set meanalcoholq2 precision mean [alcohol / sqrt(housesize)] of patches with [occupied = 1 and quintile = 2] 2
  set meanclothingq2 precision mean [clothing / sqrt(housesize)] of patches with [occupied = 1 and quintile = 2] 2
  set meanhousingq2 precision mean [housing / sqrt(housesize)] of patches with [occupied = 1 and quintile = 2] 2
  set meanfurnitureq2 precision mean [furniture / sqrt(housesize)] of patches with [occupied = 1 and quintile = 2] 2
  set meanhealthq2 precision mean [health / sqrt(housesize)] of patches with [occupied = 1 and quintile = 2] 2
  set meantransportq2 precision mean [transport / sqrt(housesize)] of patches with [occupied = 1 and quintile = 2] 2
  set meancommunicationq2 precision mean [communication / sqrt(housesize)] of patches with [occupied = 1 and quintile = 2] 2
  set meanrecreationq2 precision mean [recreation / sqrt(housesize)] of patches with [occupied = 1 and quintile = 2] 2
  set meaneducq2 precision mean [educ / sqrt(housesize)] of patches with [occupied = 1 and quintile = 2] 2
  set meanhotelsq2 precision mean [hotels / sqrt(housesize)] of patches with [occupied = 1 and quintile = 2] 2
  set meanmiscq2 precision mean [misc / sqrt(housesize)] of patches with [occupied = 1 and quintile = 2] 2
  set meanotherexpq2 precision mean [otherexp / sqrt(housesize)] of patches with [occupied = 1 and quintile = 2] 2

; quintile3 means
  set housesq3 count patches with [occupied = 1 and quintile = 3]
  set meanexpq3 precision mean [totexp / sqrt(housesize)] of patches with [occupied = 1 and quintile = 3] 2
  set meanincomeq3 precision mean [incanon / sqrt(housesize)] of patches with [occupied = 1 and quintile = 3] 2
  set meanfoodq3 precision mean [food / sqrt(housesize)] of patches with [occupied = 1 and quintile = 3] 2
  set meanalcoholq3 precision mean [alcohol / sqrt(housesize)] of patches with [occupied = 1 and quintile = 3] 2
  set meanclothingq3 precision mean [clothing / sqrt(housesize)] of patches with [occupied = 1 and quintile = 3] 2
  set meanhousingq3 precision mean [housing / sqrt(housesize)] of patches with [occupied = 1 and quintile = 3] 2
  set meanfurnitureq3 precision mean [furniture / sqrt(housesize)] of patches with [occupied = 1 and quintile = 3] 2
  set meanhealthq3 precision mean [health / sqrt(housesize)] of patches with [occupied = 1 and quintile = 3] 2
  set meantransportq3 precision mean [transport / sqrt(housesize)] of patches with [occupied = 1 and quintile = 3] 2
  set meancommunicationq3 precision mean [communication / sqrt(housesize)] of patches with [occupied = 1 and quintile = 3] 2
  set meanrecreationq3 precision mean [recreation / sqrt(housesize)] of patches with [occupied = 1 and quintile = 3] 2
  set meaneducq3 precision mean [educ / sqrt(housesize)] of patches with [occupied = 1 and quintile = 3] 2
  set meanhotelsq3 precision mean [hotels / sqrt(housesize)] of patches with [occupied = 1 and quintile = 3] 2
  set meanmiscq3 precision mean [misc / sqrt(housesize)] of patches with [occupied = 1 and quintile = 3] 2
  set meanotherexpq3 precision mean [otherexp / sqrt(housesize)] of patches with [occupied = 1 and quintile = 3] 2

; quintile4 means
  set housesq4 count patches with [occupied = 1 and quintile = 4]
  set meanexpq4 precision mean [totexp / sqrt(housesize)] of patches with [occupied = 1 and quintile = 4] 2
  set meanincomeq4 precision mean [incanon / sqrt(housesize)] of patches with [occupied = 1 and quintile = 4] 2
  set meanfoodq4 precision mean [food / sqrt(housesize)] of patches with [occupied = 1 and quintile = 4] 2
  set meanalcoholq4 precision mean [alcohol / sqrt(housesize)] of patches with [occupied = 1 and quintile = 4] 2
  set meanclothingq4 precision mean [clothing / sqrt(housesize)] of patches with [occupied = 1 and quintile = 4] 2
  set meanhousingq4 precision mean [housing / sqrt(housesize)] of patches with [occupied = 1 and quintile = 4] 2
  set meanfurnitureq4 precision mean [furniture / sqrt(housesize)] of patches with [occupied = 1 and quintile = 4] 2
  set meanhealthq4 precision mean [health / sqrt(housesize)] of patches with [occupied = 1 and quintile = 4] 2
  set meantransportq4 precision mean [transport / sqrt(housesize)] of patches with [occupied = 1 and quintile = 4] 2
  set meancommunicationq4 precision mean [communication / sqrt(housesize)] of patches with [occupied = 1 and quintile = 4] 2
  set meanrecreationq4 precision mean [recreation / sqrt(housesize)] of patches with [occupied = 1 and quintile = 4] 2
  set meaneducq4 precision mean [educ / sqrt(housesize)] of patches with [occupied = 1 and quintile = 4] 2
  set meanhotelsq4 precision mean [hotels / sqrt(housesize)] of patches with [occupied = 1 and quintile = 4] 2
  set meanmiscq4 precision mean [misc / sqrt(housesize)] of patches with [occupied = 1 and quintile = 4] 2
  set meanotherexpq4 precision mean [otherexp / sqrt(housesize)] of patches with [occupied = 1 and quintile = 4] 2

; quintile5 means
  set housesq5 count patches with [occupied = 1 and quintile = 5]
  set meanexpq5 precision mean [totexp / sqrt(housesize)] of patches with [occupied = 1 and quintile = 5] 2
  set meanincomeq5 precision mean [incanon / sqrt(housesize)] of patches with [occupied = 1 and quintile = 5] 2
  set meanfoodq5 precision mean [food / sqrt(housesize)] of patches with [occupied = 1 and quintile = 5] 2
  set meanalcoholq5 precision mean [alcohol / sqrt(housesize)] of patches with [occupied = 1 and quintile = 5] 2
  set meanclothingq5 precision mean [clothing / sqrt(housesize)] of patches with [occupied = 1 and quintile = 5] 2
  set meanhousingq5 precision mean [housing / sqrt(housesize)] of patches with [occupied = 1 and quintile = 5] 2
  set meanfurnitureq5 precision mean [furniture / sqrt(housesize)] of patches with [occupied = 1 and quintile = 5] 2
  set meanhealthq5 precision mean [health / sqrt(housesize)] of patches with [occupied = 1 and quintile = 5] 2
  set meantransportq5 precision mean [transport / sqrt(housesize)] of patches with [occupied = 1 and quintile = 5] 2
  set meancommunicationq5 precision mean [communication / sqrt(housesize)] of patches with [occupied = 1 and quintile = 5] 2
  set meanrecreationq5 precision mean [recreation / sqrt(housesize)] of patches with [occupied = 1 and quintile = 5] 2
  set meaneducq5 precision mean [educ / sqrt(housesize)] of patches with [occupied = 1 and quintile = 5] 2
  set meanhotelsq5 precision mean [hotels / sqrt(housesize)] of patches with [occupied = 1 and quintile = 5] 2
  set meanmiscq5 precision mean [misc / sqrt(housesize)] of patches with [occupied = 1 and quintile = 5] 2
  set meanotherexpq5 precision mean [otherexp / sqrt(housesize)] of patches with [occupied = 1 and quintile = 5] 2

  set pcexpcommunication (totcommunication / totexp) * 100
  set pcexpseconddwelling (totseconddwelling / totexp) * 100
  set pcexpclothing (totclothing / totexp) * 100
  set pcexpinternet (totinternet / totexp) * 100
  set pcexpsaved (totsaved / totexp) * 100
  set pcexptelecom (tottelecom / totexp) * 100
  set pcexpnontelecom (totnontelecom / totexp) * 100
  
  set pcexpfood precision ((totfood / totexp) * 100) 2
  set pcexpalcohol precision ((totalcohol / totexp) * 100) 2
  set pcexpclothing precision ((totclothing / totexp) * 100) 2
  set pcexphousing precision ((tothousing / totexp) * 100) 2
  set pcexpfurniture precision ((totfurniture / totexp) * 100) 2
  set pcexphealth precision ((tothealth / totexp) * 100) 2
  set pcexptransport precision ((tottransport / totexp) * 100) 2
  set pcexpcommunication precision ((totcommunication / totexp) * 100) 2
  set pcexprecreation precision ((totrecreation / totexp) * 100) 2
  set pcexpeduc precision ((toteduc / totexp) * 100) 2
  set pcexphotels precision ((tothotels / totexp) * 100) 2
  set pcexpmisc precision ((totmisc / totexp) * 100) 2
  set pcexpotherexp precision ((tototherexp / totexp) * 100) 2
  
  set epcexpfood precision ((etotfood / etotexp) * 100) 2
  set epcexpalcohol precision ((etotalcohol / etotexp) * 100) 2
  set epcexpclothing precision ((etotclothing / etotexp) * 100) 2
  set epcexphousing precision ((etothousing / etotexp) * 100) 2
  set epcexpfurniture precision ((etotfurniture / etotexp) * 100) 2
  set epcexphealth precision ((etothealth / etotexp) * 100) 2
  set epcexptransport precision ((etottransport / etotexp) * 100) 2
  set epcexpcommunication precision ((etotcommunication / etotexp) * 100) 2
  set epcexprecreation precision ((etotrecreation / etotexp) * 100) 2
  set epcexpeduc precision ((etoteduc / etotexp) * 100) 2
  set epcexphotels precision ((etothotels / etotexp) * 100) 2
  set epcexpmisc precision ((etotmisc / etotexp) * 100) 2
  set epcexpotherexp precision ((etototherexp / etotexp) * 100) 2  
  
  set pcincseconddwelling (totseconddwelling / totincome) * 100
  set pcincinternet (totinternet / totincome) * 100
  set pcincsaved (totsaved / totincome) * 100
  set pcinctelecom (tottelecom / totincome) * 100
  set pcincnontelecom (totnontelecom / totincome) * 100
  
  set low count patches with [occupied = 1 and incanon > 0 and incanon < 300]
  set medium count patches with [occupied = 1 and incanon >= 300 and incanon < 800]
  set high count patches with [occupied = 1 and incanon >= 800]
  set othergroup count patches with [occupied = 1 and currenttype = 6]

  set pclow ((count patches with [occupied = 1 and incanon > 0 and incanon < 300]) / houses) * 100
  set pcmedium ((count patches with [occupied = 1 and incanon >= 300 and incanon < 800]) / houses) * 100
  set pchigh ((count patches with [occupied = 1 and incanon >= 800]) / houses) * 100
   
  ; write low write medium write high

  set flow sum[seconddwelling] of patches with [occupied = 1 and currenttype >= 10 and currenttype <= 15] ; average second dwelling spend for each income group
  if low > 0 [set mflow (flow / low)]
  set fmed sum[seconddwelling] of patches with [occupied = 1 and currenttype >= 20 and currenttype <= 25]
  if medium > 0 [set mfmed (fmed / medium)]
  set fhigh sum[seconddwelling] of patches with [occupied = 1 and currenttype >= 30 and currenttype <= 35]
  if high > 0 [set mfhigh (fhigh / high)]
  set fother sum[seconddwelling] of patches with [occupied = 1 and currenttype = 6]

  set type1pc ((count patches with [occupied = 1 and currenttype = 1]) / houses) * 100
  set type2pc ((count patches with [occupied = 1 and currenttype = 2]) / houses) * 100
  set type3pc ((count patches with [occupied = 1 and currenttype = 3]) / houses) * 100 
  set type4pc ((count patches with [occupied = 1 and currenttype = 4]) / houses) * 100
  set type5pc ((count patches with [occupied = 1 and currenttype = 5]) / houses) * 100 
  set type6pc ((count patches with [occupied = 1 and currenttype = 6]) / houses) * 100

  ; outputs for type 2: household headed by person aged over 65
  set etotfood2 sum [food / sqrt(housesize)] of patches with [occupied = 1 and currenttype = 2]
  set etotalcohol2 sum [alcohol / sqrt(housesize)] of patches with [occupied = 1 and currenttype = 2]    
  set etotclothing2 sum [clothing / sqrt(housesize)] of patches with [occupied = 1 and currenttype = 2]  
  set etothousing2 sum [housing / sqrt(housesize)] of patches with [occupied = 1 and currenttype = 2]
  set etotfurniture2 sum [furniture / sqrt(housesize)] of patches with [occupied = 1 and currenttype = 2]
  set etothealth2 sum [health / sqrt(housesize)] of patches with [occupied = 1 and currenttype = 2]
  set etottransport2 sum [transport / sqrt(housesize)] of patches with [occupied = 1 and currenttype = 2]
  set etotcommunication2 sum [communication / sqrt(housesize)] of patches with [occupied = 1 and currenttype = 2]
  set etotrecreation2 sum [recreation / sqrt(housesize)] of patches with [occupied = 1 and currenttype = 2]
  set etoteduc2 sum [educ / sqrt(housesize)] of patches with [occupied = 1 and currenttype = 2]
  set etothotels2 sum [hotels / sqrt(housesize)] of patches with [occupied = 1 and currenttype = 2]  
  set etotmisc2 sum [misc / sqrt(housesize)] of patches with [occupied = 1 and currenttype = 2]
  set etototherexp2 sum [otherexp / sqrt(housesize)] of patches with [occupied = 1 and currenttype = 2]
  
  set emeanincome2 precision (etotincome2 / houses2) 2
  set emeanexp2 precision (etotexp4 / houses4) 2
  set emeanfood2 precision (etotfood2 / houses2) 2
  set emeanalcohol2 precision (etotalcohol2 / houses2) 2
  set emeanclothing2 precision (etotclothing2 / houses2) 2  
  set emeanhousing2 precision (etothousing2 / houses2) 2
  set emeanfurniture2 precision (etotfurniture2 / houses2) 2
  set emeanhealth2 precision (etothealth2 / houses2) 2
  set emeantransport2 precision (etottransport2 / houses2) 2
  set emeancommunication2 precision (etotcommunication2 / houses2) 2
  set emeanrecreation2 precision (etotrecreation2 / houses2) 2
  set emeaneduc2 precision (etoteduc2 / houses2) 2
  set emeanhotels2 precision (etothotels2 / houses2) 2
  set emeanmisc2 precision (etotmisc2 / houses2) 2
  set emeanotherexp2 precision (etototherexp2 / houses2) 2
  
  set epcexpfood2 precision ((emeanfood2 / emeanfood) * 100) 2
  set epcexpalcohol2 precision ((emeanalcohol2 / emeanalcohol) * 100) 2
  set epcexpclothing2 precision ((emeanclothing2 / emeanclothing) * 100) 2
  set epcexphousing2 precision ((emeanhousing2 / emeanhousing) * 100) 2
  set epcexpfurniture2 precision ((emeanfurniture2 / emeanfurniture) * 100) 2
  set epcexphealth2 precision ((emeanhealth2 / emeanhealth) * 100) 2
  set epcexptransport2 precision ((emeantransport2 / emeantransport) * 100) 2
  set epcexpcommunication2 precision ((emeancommunication2 / emeancommunication) * 100) 2
  set epcexprecreation2 precision ((emeanrecreation2 / emeanrecreation) * 100) 2
  set epcexpeduc2 precision ((emeaneduc2 / emeaneduc) * 100) 2
  set epcexphotels2 precision ((emeanhotels2 / emeanhotels) * 100) 2
  set epcexpmisc2 precision ((emeanmisc2 / emeanmisc) * 100) 2
  set epcexpotherexp2 precision ((emeanotherexp2 / emeanotherexp) * 100) 2
  
  ; outputs for type 4: family with child under 5
  set etotfood4 sum [food / sqrt(housesize)] of patches with [occupied = 1 and currenttype = 4]
  set etotalcohol4 sum [alcohol / sqrt(housesize)] of patches with [occupied = 1 and currenttype = 4]    
  set etotclothing4 sum [clothing / sqrt(housesize)] of patches with [occupied = 1 and currenttype = 4]  
  set etothousing4 sum [housing / sqrt(housesize)] of patches with [occupied = 1 and currenttype = 4]
  set etotfurniture4 sum [furniture / sqrt(housesize)] of patches with [occupied = 1 and currenttype = 4]
  set etothealth4 sum [health / sqrt(housesize)] of patches with [occupied = 1 and currenttype = 4]
  set etottransport4 sum [transport / sqrt(housesize)] of patches with [occupied = 1 and currenttype = 4]
  set etotcommunication4 sum [communication / sqrt(housesize)] of patches with [occupied = 1 and currenttype = 4]
  set etotrecreation4 sum [recreation / sqrt(housesize)] of patches with [occupied = 1 and currenttype = 4]  
  set etoteduc4 sum [educ / sqrt(housesize)] of patches with [occupied = 1 and currenttype = 4]  
  set etothotels4 sum [hotels / sqrt(housesize)] of patches with [occupied = 1 and currenttype = 4]  
  set etotmisc4 sum [misc / sqrt(housesize)] of patches with [occupied = 1 and currenttype = 4]  
  set etototherexp4 sum [otherexp / sqrt(housesize)] of patches with [occupied = 1 and currenttype = 4]
  
  set emeanincome4 precision (etotincome4 / houses4) 2
  set emeanexp4 precision (etotexp4 / houses4) 2
  set emeanfood4 precision (etotfood4 / houses4) 2
  set emeanalcohol4 precision (etotalcohol4 / houses4) 2
  set emeanclothing4 precision (etotclothing4 / houses4) 2  
  set emeanhousing4 precision (etothousing4 / houses4) 2
  set emeanfurniture4 precision (etotfurniture4 / houses4) 2
  set emeanhealth4 precision (etothealth4 / houses4) 2
  set emeantransport4 precision (etottransport4 / houses4) 2
  set emeancommunication4 precision (etotcommunication4 / houses4) 2
  set emeanrecreation4 precision (etotrecreation4 / houses4) 2
  set emeaneduc4 precision (etoteduc4 / houses4) 2
  set emeanhotels4 precision (etothotels4 / houses4) 2
  set emeanmisc4 precision (etotmisc4 / houses4) 2
  set emeanotherexp4 precision (etototherexp4 / houses4) 2  
  
  set epcexpfood4 precision ((emeanfood4 / emeanfood) * 100) 2
  set epcexpalcohol4 precision ((emeanalcohol4 / emeanalcohol) * 100) 2
  set epcexpclothing4 precision ((emeanclothing4 / emeanclothing) * 100) 2
  set epcexphousing4 precision ((emeanhousing4 / emeanhousing) * 100) 2
  set epcexpfurniture4 precision ((emeanfurniture4 / emeanfurniture) * 100) 2
  set epcexphealth4 precision ((emeanhealth4 / emeanhealth) * 100) 2
  set epcexptransport4 precision ((emeantransport4 / emeantransport) * 100) 2
  set epcexpcommunication4 precision ((emeancommunication4 / emeancommunication) * 100) 2
  set epcexprecreation4 precision ((emeanrecreation4 / emeanrecreation) * 100) 2
  set epcexpeduc4 precision ((emeaneduc4 / emeaneduc) * 100) 2
  set epcexphotels4 precision ((emeanhotels4 / emeanhotels) * 100) 2
  set epcexpmisc4 precision ((emeanmisc4 / emeanmisc) * 100) 2
  set epcexpotherexp4 precision ((emeanotherexp4 / emeanotherexp) * 100) 2
  
  show "medians"
  show median [incanon] of patches with [occupied = 1]
  show median [totalexpenditure] of patches with [occupied = 1]
  show median [food] of patches with [occupied = 1]
  show median [housing] of patches with [occupied = 1]
  show median [recreation] of patches with [occupied = 1]
  show median [transport] of patches with [occupied = 1]  
  show "----"
end

to followparent
  let tempid 0
  let r 0.0
  set r random-float 1
  if r < 0.5 [
    ask turtles with [age <= 25 and status != "married" and status != "cohabiting" and student = 0 and parentid > 0] [
      set tempid parentid
      if any? turtles with [who = tempid] [move-to turtle parentid]
    ]  
  ]  
end

to writetofile
  file-open "outputmeans.dat"
  if years = 0 [
    file-write "Years"
    file-write "Food"
    file-write "Alcohol"
    file-write "Clothing"
    file-write "Housing"
    file-write "Furniture"
    file-write "Health"
    file-write "Transport"
    file-write "Communication"
    file-write "Recreation"
    file-write "Education"
    file-write "Hotels"
    file-write "Miscellaneous"
    file-write "Total Expenditure"
    file-write "Mean Income"
    file-print " "
  ]  
  file-open "outputmeans.dat"
  file-write years
  file-write meanfood
  file-write meanalcohol
  file-write meanclothing
  file-write meanhousing
  file-write meanfurniture
  file-write meanhealth
  file-write meantransport
  file-write meancommunication
  file-write meanrecreation
  file-write meaneduc
  file-write meanhotels
  file-write meanmisc
  file-write meanexp
  file-write meanincome
  file-print " "
  file-close
 
  file-open "outputq1means.dat"
  if years = 0 [
    file-write "Years"
    file-write "Food"
    file-write "Alcohol"
    file-write "Clothing"
    file-write "Housing"
    file-write "Furniture"
    file-write "Health"
    file-write "Transport"
    file-write "Communication"
    file-write "Recreation"
    file-write "Education"
    file-write "Hotels"
    file-write "Miscellaneous"
    file-write "Total Expenditure"
    file-write "Mean Income"
    file-print " "
  ]
  file-write years
  file-write meanfoodq1
  file-write meanalcoholq1
  file-write meanclothingq1
  file-write meanhousingq1
  file-write meanfurnitureq1
  file-write meanhealthq1
  file-write meantransportq1
  file-write meancommunicationq1
  file-write meanrecreationq1
  file-write meaneducq1
  file-write meanhotelsq1
  file-write meanmiscq1
  file-write meanexpq1
  file-write meanincomeq1
  file-print " "  
  file-close
  
  file-open "outputq2means.dat"
  if years = 0 [
    file-write "Years"
    file-write "Food"
    file-write "Alcohol"
    file-write "Clothing"
    file-write "Housing"
    file-write "Furniture"
    file-write "Health"
    file-write "Transport"
    file-write "Communication"
    file-write "Recreation"
    file-write "Education"
    file-write "Hotels"
    file-write "Miscellaneous"
    file-write "Total Expenditure"
    file-write "Mean Income"
    file-print " "
  ]
  file-write years
  file-write meanfoodq2
  file-write meanalcoholq2
  file-write meanclothingq2
  file-write meanhousingq2
  file-write meanfurnitureq2
  file-write meanhealthq2
  file-write meantransportq2
  file-write meancommunicationq2
  file-write meanrecreationq2
  file-write meaneducq2
  file-write meanhotelsq2
  file-write meanmiscq2
  file-write meanexpq2
  file-write meanincomeq2
  file-print " "  
  file-close

  file-open "outputq3means.dat"
  if years = 0 [
    file-write "Years"
    file-write "Food"
    file-write "Alcohol"
    file-write "Clothing"
    file-write "Housing"
    file-write "Furniture"
    file-write "Health"
    file-write "Transport"
    file-write "Communication"
    file-write "Recreation"
    file-write "Education"
    file-write "Hotels"
    file-write "Miscellaneous"
    file-write "Total Expenditure"
    file-write "Mean Income"
    file-print " "
  ]
  file-write years
  file-write meanfoodq3
  file-write meanalcoholq3
  file-write meanclothingq3
  file-write meanhousingq3
  file-write meanfurnitureq3
  file-write meanhealthq3
  file-write meantransportq3
  file-write meancommunicationq3
  file-write meanrecreationq3
  file-write meaneducq3
  file-write meanhotelsq3
  file-write meanmiscq3
  file-write meanexpq3
  file-write meanincomeq3
  file-print " "  
  file-close

  file-open "outputq4means.dat"
  if years = 0 [
    file-write "Years"
    file-write "Food"
    file-write "Alcohol"
    file-write "Clothing"
    file-write "Housing"
    file-write "Furniture"
    file-write "Health"
    file-write "Transport"
    file-write "Communication"
    file-write "Recreation"
    file-write "Education"
    file-write "Hotels"
    file-write "Miscellaneous"
    file-write "Total Expenditure"
    file-write "Mean Income"
    file-print " "
  ]
  file-write years
  file-write meanfoodq4
  file-write meanalcoholq4
  file-write meanclothingq4
  file-write meanhousingq4
  file-write meanfurnitureq4
  file-write meanhealthq4
  file-write meantransportq4
  file-write meancommunicationq4
  file-write meanrecreationq4
  file-write meaneducq4
  file-write meanhotelsq4
  file-write meanmiscq4
  file-write meanexpq4
  file-write meanincomeq4
  file-print " "  
  file-close

  file-open "outputq5means.dat"
  if years = 0 [
    file-write "Years"
    file-write "Food"
    file-write "Alcohol"
    file-write "Clothing"
    file-write "Housing"
    file-write "Furniture"
    file-write "Health"
    file-write "Transport"
    file-write "Communication"
    file-write "Recreation"
    file-write "Education"
    file-write "Hotels"
    file-write "Miscellaneous"
    file-write "Total Expenditure"
    file-write "Mean Income"
    file-print " "
  ]
  file-write years
  file-write meanfoodq5
  file-write meanalcoholq5
  file-write meanclothingq5
  file-write meanhousingq5
  file-write meanfurnitureq5
  file-write meanhealthq5
  file-write meantransportq5
  file-write meancommunicationq5
  file-write meanrecreationq5
  file-write meaneducq5
  file-write meanhotelsq5
  file-write meanmiscq5
  file-write meanexpq5
  file-write meanincomeq5
  file-print " "  
  file-close
   
  file-open "outputpc.dat"
  if years = 0 [
    file-write "Total Expenditure"
    file-write "Food"
    file-write "Alcohol"
    file-write "Clothing"
    file-write "Housing"
    file-write "Furniture"
    file-write "Health"
    file-write "Transport"
    file-write "Communication"
    file-write "Recreation"
    file-write "Education"
    file-write "Hotels"
    file-write "Miscellaneous"
    file-write "Total Expenditure"
    file-write "Mean Income"
    file-print " "
  ]
  file-write meanexp 
  file-write pcexpfood
  file-write pcexpalcohol
  file-write pcexpclothing
  file-write pcexphousing
  file-write pcexpfurniture
  file-write pcexphealth
  file-write pcexptransport
  file-write pcexpcommunication
  file-write pcexprecreation
  file-write pcexpeduc
  file-write pcexphotels
  file-write pcexpmisc
  file-write pcexpotherexp
  file-write meanincome
  file-print " "
  file-close

  file-open "outputpc2.dat"
  if years = 0 [
    file-write "Years"
    file-write "Food"
    file-write "Alcohol"
    file-write "Clothing"
    file-write "Housing"
    file-write "Furniture"
    file-write "Health"
    file-write "Transport"
    file-write "Communication"
    file-write "Recreation"
    file-write "Education"
    file-write "Hotels"
    file-write "Miscellaneous"
    file-write "Total Expenditure" 
    file-print " "
  ]
  file-write years
  file-write epcexpfood2
  file-write epcexpalcohol2
  file-write epcexpclothing2
  file-write epcexphousing2
  file-write epcexpfurniture2
  file-write epcexphealth2
  file-write epcexptransport2
  file-write epcexpcommunication2
  file-write epcexprecreation2
  file-write epcexpeduc2
  file-write epcexphotels2
  file-write epcexpmisc2
  file-write emeanexp2
  file-print " "
  file-close
  
  file-open "outputpc4.dat"
  if years = 0 [
    file-write "Years"
    file-write "Food"
    file-write "Alcohol"
    file-write "Clothing"
    file-write "Housing"
    file-write "Furniture"
    file-write "Health"
    file-write "Transport"
    file-write "Communication"
    file-write "Recreation"
    file-write "Education"
    file-write "Hotels"
    file-write "Miscellaneous"
    file-write "Total Expenditure" 
    file-print " "
  ]
  file-write years
  file-write epcexpfood4
  file-write epcexpalcohol4
  file-write epcexpclothing4
  file-write epcexphousing4
  file-write epcexpfurniture4
  file-write epcexphealth4
  file-write epcexptransport4
  file-write epcexpcommunication4
  file-write epcexprecreation4
  file-write epcexpeduc4
  file-write epcexphotels4
  file-write epcexpmisc4
  file-write emeanexp4
  file-print " "
  file-close
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; look up tables
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to setagebands
  set under20 0 set twenties 0 set thirties 0
  set forties 0 set fifties 0 set sixties 0
        
  if age < 20 [set under20 1]
  if age >= 20 and age < 30 [set twenties 1]
  if age >= 30 and age < 40 [set thirties 1]
  if age >= 40 and age < 50 [set forties 1]
  if age >= 50 and age < 60 [set fifties 1]
  if age >= 60 [set sixties 1]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; plotting section
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to update-plot
  set-current-plot "Expenditures"
  set-current-plot-pen "food"
  plot meanfood
  set-current-plot-pen "alcohol"
  plot meanalcohol
  set-current-plot-pen "clothing"
  plot totclothing / houses
  set-current-plot-pen "housing"
  plot tothousing / houses  
  set-current-plot-pen "furniture"
  plot totfurniture / houses  
  set-current-plot-pen "health"
  plot tothealth / houses  
  set-current-plot-pen "transport"
  plot tottransport / houses  
  set-current-plot-pen "communication"
  plot totcommunication / houses  
  set-current-plot-pen "recreation"
  plot totrecreation / houses  
  set-current-plot-pen "educ"
  plot toteduc / houses
  set-current-plot-pen "hotels"
  plot tothotels / houses
  set-current-plot-pen "misc"
  plot totmisc / houses
  set-current-plot-pen "otherexp"
  plot tototherexp / houses  

  set-current-plot "Share of Income"
  set-current-plot-pen "pcexpfood"
  plot pcexpfood
  set-current-plot-pen "pcexpalcohol"
  plot pcexpalcohol
  set-current-plot-pen "pcexpclothing"
  plot pcexpclothing  
  set-current-plot-pen "pcexphousing"
  plot pcexphousing
  set-current-plot-pen "pcexpfurniture"
  plot pcexpfurniture
  set-current-plot-pen "pcexphealth"
  plot pcexphealth
  set-current-plot-pen "pcexptransport"
  plot pcexptransport
  set-current-plot-pen "pcexpcommunication"
  plot pcexpcommunication
  set-current-plot-pen "pcexprecreation"
  plot pcexprecreation
  set-current-plot-pen "pcexpeduc"
  plot pcexpeduc
  set-current-plot-pen "pcexphotels"
  plot pcexphotels
  set-current-plot-pen "pcexpmisc"
  plot pcexpmisc
  set-current-plot-pen "pcexpotherexp"
  plot pcexpotherexp

  set-current-plot "population"
  plot pop
  
  set-current-plot "housesize"
  plot hsize
  
  set-current-plot "Expenditures_1"
  set-current-plot-pen "food"
  plot totfood / houses
  set-current-plot-pen "alcohol"
  plot totalcohol / houses
  set-current-plot-pen "clothing"
  plot totclothing / houses
  set-current-plot-pen "housing"
  plot tothousing / houses  
  set-current-plot-pen "furniture"
  plot totfurniture / houses  
  set-current-plot-pen "health"
  plot tothealth / houses  

  set-current-plot "Expenditures_2"
  set-current-plot-pen "transport"
  plot tottransport / houses  
  set-current-plot-pen "communication"
  plot totcommunication / houses  
  set-current-plot-pen "recreation"
  plot totrecreation / houses  
  set-current-plot-pen "educ"
  plot toteduc / houses
  set-current-plot-pen "hotels"
  plot tothotels / houses
  set-current-plot-pen "misc"
  plot totmisc / houses
  set-current-plot-pen "otherexp"
  plot tototherexp / houses  

  set-current-plot "Mean Weekly Household Income"
  plot (totincome / houses)
  
  set-current-plot "effectiveincome"
  plot (toteffectiveincome / houses) 
   
  set-current-plot "Share of Income 1"
  set-current-plot-pen "pcexpfood"
  plot pcexpfood
  set-current-plot-pen "pcexpalcohol"
  plot pcexpalcohol
  set-current-plot-pen "pcexpclothing"
  plot pcexpclothing  
  set-current-plot-pen "pcexphousing"
  plot pcexphousing
  set-current-plot-pen "pcexpfurniture"
  plot pcexpfurniture
  set-current-plot-pen "pcexphealth"
  plot pcexphealth

  set-current-plot "Share of Income 2"
  set-current-plot-pen "pcexptransport"
  plot pcexptransport
  set-current-plot-pen "pcexpcommunication"
  plot pcexpcommunication
  set-current-plot-pen "pcexprecreation"
  plot pcexprecreation
  set-current-plot-pen "pcexpeduc"
  plot pcexpeduc
  set-current-plot-pen "pcexphotels"
  plot pcexphotels
  set-current-plot-pen "pcexpmisc"
  plot pcexpmisc
  set-current-plot-pen "pcexpotherexp"
  plot pcexpotherexp
  
  set-current-plot "Population Makeup"
  set-current-plot-pen "pcsingle"
  plot pcsingle
  set-current-plot-pen "pcmarried"
  plot pcmarried
  set-current-plot-pen "pccohab"
  plot pccohab
  set-current-plot-pen "pcseparated"
  plot pcseparated
  set-current-plot-pen "pcdivorced"
  plot pcdivorced  
  set-current-plot-pen "pcwidowed"
  plot pcwidowed
  
  set-current-plot "Household Size"
  set-current-plot-pen "h1"
  plot h1
  set-current-plot-pen "h2"
  plot h2
  set-current-plot-pen "h3"
  plot h3
  set-current-plot-pen "h4"
  plot h4
  
  set-current-plot "incomeband"
  set-current-plot-pen "pclow"
  plot pclow
  set-current-plot-pen "pcmedium"
  plot pcmedium
  set-current-plot-pen "pchigh"
  plot pchigh
  
  set-current-plot "quartile_counts"
  set-current-plot-pen "q1"
  plot q1
  set-current-plot-pen "q2"
  plot q2
  set-current-plot-pen "q3"
  plot q3
  set-current-plot-pen "q4"
  plot q4
  
  set-current-plot "types"
  set-plot-x-range 0 9
  set-plot-y-range 0 100
  set-histogram-num-bars 8
  histogram [currenttype] of patches with [occupied = 1]
end
@#$#@#$#@
GRAPHICS-WINDOW
9
1013
622
1647
100
100
3.0
1
10
1
1
1
0
0
0
1
-100
100
-100
100
0
0
1
ticks
30.0

BUTTON
6
70
144
117
Setup
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
6
123
144
169
go
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
319
702
622
849
Population
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

PLOT
339
858
596
993
Housesize
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

INPUTBOX
7
177
111
237
Households
1000000
1
0
Number

INPUTBOX
7
241
111
301
stop_after
10
1
0
Number

MONITOR
8
305
73
350
NIL
years
0
1
11

PLOT
632
724
888
874
Population Makeup
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"pcmarried" 1.0 0 -16777216 true "" ""
"pcsingle" 1.0 0 -13791810 true "" ""
"pccohab" 1.0 0 -1184463 true "" ""
"pcseparated" 1.0 0 -10899396 true "" ""
"pcwidowed" 1.0 0 -7500403 true "" ""
"pcdivorced" 1.0 0 -955883 true "" ""

MONITOR
711
879
778
924
NIL
pcmarried
1
1
11

MONITOR
649
879
706
924
NIL
pcsingle
1
1
11

MONITOR
782
879
841
924
NIL
pccohab
1
1
11

MONITOR
783
935
853
980
NIL
pcseparated
1
1
11

MONITOR
714
934
778
979
NIL
pcwidowed
1
1
11

MONITOR
649
933
710
978
NIL
pcdivorced
1
1
11

PLOT
630
992
856
1142
Household Size
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"h1" 1.0 0 -16777216 true "" ""
"h2" 1.0 0 -6459832 true "" ""
"h3" 1.0 0 -2674135 true "" ""
"h4" 1.0 0 -10899396 true "" ""

MONITOR
616
1146
673
1191
NIL
h1
1
1
11

MONITOR
680
1146
737
1191
NIL
h2
1
1
11

MONITOR
745
1146
802
1191
NIL
h3
1
1
11

MONITOR
810
1147
867
1192
NIL
h4
1
1
11

PLOT
5
539
311
689
Mean Weekly Household Income
Years
£
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"income" 1.0 1 -2674135 true "" ""

PLOT
6
699
311
849
incomeband
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"pclow" 1.0 0 -2674135 true "" ""
"pcmedium" 1.0 0 -1184463 true "" ""
"pchigh" 1.0 0 -10899396 true "" ""

PLOT
672
251
1051
486
Share of Income 1
Years
%
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"pcexpfood" 1.0 0 -10899396 true "" ""
"pcexpalcohol" 1.0 0 -1184463 true "" ""
"pcexpclothing" 1.0 0 -2064490 true "" ""
"pcexphousing" 1.0 0 -2674135 true "" ""
"pcexpfurniture" 1.0 0 -6459832 true "" ""
"pcexphealth" 1.0 0 -13791810 true "" ""

PLOT
318
540
624
690
effectiveincome
Years
£ per week
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"effectiveincome" 1.0 1 -10899396 true "" ""

PLOT
672
10
1051
244
Expenditures_1
Years
£ per week
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"food" 1.0 0 -10899396 true "" ""
"alcohol" 1.0 0 -1184463 true "" ""
"clothing" 1.0 0 -2064490 true "" ""
"housing" 1.0 0 -2674135 true "" ""
"furniture" 1.0 0 -6459832 true "" ""
"health" 1.0 0 -14835848 true "" ""

PLOT
1065
10
1442
243
Expenditures_2
Years
£ per week
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"transport" 1.0 0 -16777216 true "" ""
"communication" 1.0 0 -1184463 true "" ""
"recreation" 1.0 0 -13840069 true "" ""
"educ" 1.0 0 -5825686 true "" ""
"hotels" 1.0 0 -7500403 true "" ""
"misc" 1.0 0 -955883 true "" ""
"otherexp" 1.0 0 -2674135 true "" ""

PLOT
1065
252
1442
485
Share of Income 2
Years
%
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"pcexptransport" 1.0 0 -16777216 true "" ""
"pcexpcommunication" 1.0 0 -1184463 true "" ""
"pcexprecreation" 1.0 0 -10899396 true "" ""
"pcexpeduc" 1.0 0 -5825686 true "" ""
"pcexphotels" 1.0 0 -7500403 true "" ""
"pcexpmisc" 1.0 0 -955883 true "" ""
"pcexpotherexp" 1.0 0 -2674135 true "" ""

SLIDER
9
357
201
390
change_in_real_income%
change_in_real_income%
-50
50
5
1
1
NIL
HORIZONTAL

PLOT
6
857
332
1007
quartile_counts
years
number
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"q1" 1.0 0 -2674135 true "" ""
"q2" 1.0 0 -1184463 true "" ""
"q3" 1.0 0 -13840069 true "" ""
"q4" 1.0 0 -13791810 true "" ""

PLOT
633
539
955
719
types
Type
Count
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 1 -8630108 true "" ""

PLOT
215
10
661
271
Expenditures
Years
£ per week
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Food" 1.0 0 -10899396 true "" ""
"Alcohol" 1.0 0 -1184463 true "" ""
"Clothing" 1.0 0 -2064490 true "" ""
"Housing" 1.0 0 -955883 true "" ""
"Furniture" 1.0 0 -6459832 true "" ""
"Health" 1.0 0 -8630108 true "" ""
"Transport" 1.0 0 -16777216 true "" ""
"Communication" 1.0 0 -13840069 true "" ""
"Recreation" 1.0 0 -11221820 true "" ""
"Educ" 1.0 0 -5825686 true "" ""
"Hotels" 1.0 0 -14835848 true "" ""
"Misc" 1.0 0 -13791810 true "" ""
"Otherexp" 1.0 0 -2674135 true "" ""

PLOT
215
273
661
533
Share of Income
Years
%
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"pcexpfood" 1.0 0 -10899396 true "" ""
"pcexpalcohol" 1.0 0 -1184463 true "" ""
"pcexpclothing" 1.0 0 -2064490 true "" ""
"pcexphousing" 1.0 0 -955883 true "" ""
"pcexpfurniture" 1.0 0 -6459832 true "" ""
"pcexphealth" 1.0 0 -8630108 true "" ""
"pcexptransport" 1.0 0 -16777216 true "" ""
"pcexpcommunication" 1.0 0 -13840069 true "" ""
"pcexprecreation" 1.0 0 -11221820 true "" ""
"pcexpeduc" 1.0 0 -5825686 true "" ""
"pcexphotels" 1.0 0 -14835848 true "" ""
"pcexpmisc" 1.0 0 -13791810 true "" ""
"pcexpotherexp" 1.0 0 -2674135 true "" ""

SWITCH
75
305
203
338
Apply_weights
Apply_weights
0
1
-1000

TEXTBOX
12
10
162
62
Income Change Model
20
103.0
1

SWITCH
11
460
136
493
write_to_file
write_to_file
0
1
-1000

INPUTBOX
8
397
137
457
Min_Food
0
1
0
Number

@#$#@#$#@
## WHAT IS IT?

A program to generate changes in expenditure on the basis of  
variations in household income.

## HOW IT WORKS

As income varies, new household expenditures are found by copying from a similar  
household that already has the new income.

Total expenditures are aggreageted in the variable meanexp. This is used to calculate  
the share of expenditure for each item which is then output to the file outputmeans.dat

## HOW TO USE IT

First set how many households to model up to about 10,000. A few hundred might be a good starting value because the more there are the longer it takes to run. Then load in the data by clicking on the setup button then run the model by clicking go.  
(It can take several hours to run a large population for a number of simulated years.)

## THINGS TO NOTICE

Household expenditures for a range of EFS categories are shown on the graphs.

## THINGS TO TRY

Change parameters using the siders to see what effect different rates of change of   
income have.

## EXTENDING THE MODEL

This version outputs the budget shares and total expenditure to a file so that budget   
elasticities can be calculated. The program could be extended to calculate these itself.

## CREDITS AND REFERENCES

Developed by Tony Lawson as part of a PhD project at the University of Essex  
to develop a microsimulation of household demand. Sponsored by the ESRC and BT.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.0.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
